pub fn Callout(props: CalloutProps) -> ElementExpand description
A callout component for highlighting important content
This component provides a more prominent way to display important information with optional title and icon.
pub fn Callout(props: CalloutProps) -> ElementA callout component for highlighting important content
This component provides a more prominent way to display important information with optional title and icon.