pub fn fire_event<E: 'static>(handler: &Option<EventHandler<E>>, event: E)Expand description
Call an optional event handler with the given event.
pub fn fire_event<E: 'static>(handler: &Option<EventHandler<E>>, event: E)Call an optional event handler with the given event.