pub fn Notification(props: NotificationProps) -> ElementExpand description
A notification component for temporary messages
This component creates a temporary notification that can auto-close after a specified duration.
pub fn Notification(props: NotificationProps) -> ElementA notification component for temporary messages
This component creates a temporary notification that can auto-close after a specified duration.