Module prelude

Module prelude 

Prelude module for easy importing of all style constants and functions Prelude for complete Element Plus style system

Import everything with: use dioxus_element_plug::styles::prelude::*;

Re-exports

pub use super::core::*;
pub use super::colors::*;
pub use super::typography::*;
pub use super::spacing::*;
pub use super::borders::*;
pub use super::shadows::*;
pub use super::z_index::*;
pub use super::component_classes::*;
pub use super::simple_css_generation::*;
pub use super::theme::*;
pub use super::utilities::*;
pub use super::enhanced_output::*;
pub use super::css_snippets::*;